@@ -4,7 +4,15 @@ transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflato
 
   # Convert to tibble, if necessary
   if (class(gdp)[1] == "magpie") {
-    gdp <- tibble::as_tibble(gdp) %>% dplyr::rename(tidyselect::any_of(c("iso3c" = "region")))
+    # Check if the magpie object has 2 spatial dimensions
+    spat2 <- magclass::ndim(gdp, dim = 1) == 2
+    # Check if the magpie object has year info
+    hasYears <- !is.null(magclass::getYears(gdp))
+    # Transform to tibble and rename columns
+    gdp <- gdp %>% tibble::as_tibble() %>% dplyr::rename("iso3c" = 1)
+    if (spat2) gdp <- dplyr::rename(gdp, "spatial2" = 2)
+    if (hasYears && !spat2) gdp <- dplyr::rename(gdp, "year" = 2)
+    if (hasYears && spat2) gdp <- dplyr::rename(gdp, "year" = 3)
   }
 
   # Extract base years if they exist, and adjust string
@@ -118,7 +126,13 @@ transform_internal <- function(x, gdp, with_regions, require_year_column) {
 
   # Transform into original gdp type
   if (class(gdp)[1] == "magpie") {
-    x <- magclass::as.magpie(x, spatial = "iso3c", temporal = "year")
+    # Check if the original magpie object had 2 spatial dimensions
+    spat2 <- all(grepl("\\.", magclass::getItems(gdp, dim = 1)))
+    if (!spat2) {
+      x <- magclass::as.magpie(x, spatial = "iso3c", temporal = "year")
+    } else {
+      x <- magclass::as.magpie(x, spatial = c("iso3c", "spatial2"), temporal = "year")
+    }
     magclass::getSets(x) <- magclass::getSets(gdp)
     return(x)
   }
